@@ -15,10 +15,13 @@ args, _ = parser.parse_known_args(sys.argv)
 
 # Set up a subscriber for the source.
 # If this subscriber does not exist yet BuildFlow will create it.
-input_sub = buildflow.PubSubSource(subscription=f'projects/{args.gcp_project}/subscriptions/taxiride-sub')
+input_sub = buildflow.PubSubSource(
+    subscription=f'projects/{args.gcp_project}/subscriptions/taxiride-sub')
 # Set up a BigQuery table for the sink.
 # If this table does not exist yet BuildFlow will create it.
-output_table = buildflow.BigQuerySink(table_id=f'{args.gcp_project}.buildflow_walkthrough.taxi_ride_data')
+output_table = buildflow.BigQuerySink(
+    table_id=f'{args.gcp_project}.buildflow_walkthrough.taxi_ride_data')
+
 
 # Define an output type for our pipeline.
 # By using a dataclass we can ensure our python type hints are validated
@@ -35,12 +38,15 @@ class TaxiOutput:
     ride_status: str
     passenger_count: int
 
+
 flow = Flow()
 
+
 # Define our processor.
 @flow.processor(source=input_sub, sink=output_table)
 def process(element: Dict[str, Any]) -> TaxiOutput:
     return element
 
+
 # Run our flow.
 flow.run()
\ No newline at end of file
